import requests
import json

class user_info:
	def __init__(self, _id):
		try:
			r = requests.get('http://api.founders.gg/users/{}'.format(_id))
			json_data = r.json()[0]

			# example: [{'username': 'Xelada', 'rank': 'Admin', 'servers': '2,4', 'lastSeen': 1568418961, 'created': 0}]
			if r.status_code == 200:
				self.success = True
				self.username = json_data['username']
				self.rank = json_data['rank']
				self.servers = json_data['servers']
				self.lastSeen = json_data['lastSeen']
				self.created = json_data['created']

			# example: {"error":"This resource was not found"}
			else:
				self.success = False
				
		except:
			self.success = False

def info(_id):
	return user_info(_id)

def all():
	return {
		'Xelada': 1,
		'dylanrocks2': 56,
		'shupik': 65,
		'Xeladarocks': 66,
		'TestUser1': 71,
		'TestUser2': 72
	}


import requests
import json

class status_info:
	def __init__(self, _id):
		try:
			r = requests.get('http://api.founders.gg/status/{}'.format(_id))
			json_data = r.json()

			# example: {"Success":{"host":"108.79.43.45","port":25567}}
			if r.status_code == 200:
				json_data = json_data['Success']

				self.success = True
				self.status = True
				self.ip = json_data['host']
				self.port = json_data['port']

			# example: {"error":{"errno":"ECONNREFUSED","code":"ECONNREFUSED","syscall":"connect","address":"108.79.43.45","port":25566}}
			elif r.status_code == 500:
				json_data = json_data['error']

				self.success = True
				self.status = False
				self.ip = json_data['address']
				self.port = json_data['port']

			# example: {"error":"This resource was not found"}
			else:
				self.success = False

		except:
			self.success = False

def stat(_id):
	return status_info(_id)


import requests
import json

class server_info:
	def __init__(self, _id):
		try:
			r = requests.get('http://api.founders.gg/servers/{}'.format(_id))
			json_data = r.json()[0]

			# example: [{"domain":"founders.gg","ip":"108.79.43.45","port":25565,"name":"Founders","mRam":500,"xRam":6000,"server-jar":"spigot-1.14.4"}]
			if r.status_code == 200:
				self.success = True
				self.domain = json_data['domain']
				self.ip = json_data['ip']
				self.port = json_data['port']
				self.name = json_data['name']
				self.mRam = json_data['mRam']
				self.xRam = json_data['xRam']
				self.serverJar = json_data['server-jar']

			# example: {"error":"This resource was not found"}
			else:
				self.success = False

		except:
			self.success = False

def info(_id):
	return server_info(_id)

def all():
	return {
		'Founders': 1,
		'IAC': 2,
		'Founders 2': 3,
		'Vnlla': 4
	}


import setuptools

with open("README.md", "r") as fh:
	long_description = fh.read()

setuptools.setup(
	name="founders",
	version="0.1.0",
	author="shupik",
	description="A small package for the founders api",
	long_description=long_description,
	long_description_content_type="text/markdown",
	url="https://github.com/shupik123/FoundersApiPy",
	packages=setuptools.find_packages(),
	classifiers=[
		"Programming Language :: Python :: 3",
		"Operating System :: OS Independent",
	],
	python_requires=">=3.6",
)